/* Copyright 2013-2019 Homegear GmbH
 *
 * libhomegear-base is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * libhomegear-base is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with libhomegear-base.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU Lesser General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
*/
#ifndef LIBHOMEGEAR_BASE_SRC_DEVICEDESCRIPTION_UNITCODE_H_
#define LIBHOMEGEAR_BASE_SRC_DEVICEDESCRIPTION_UNITCODE_H_

namespace BaseLib::DeviceDescription {

enum class UnitCode : int32_t {
  kUndefined = -1,
  kSquareMeters = 0,
  kSquareFeet = 1,
  kMilliamperes = 2,
  kAmperes = 3,
  kOhms = 4,
  kVolts = 5,
  kKilovolts = 6,
  kMegavolts = 7,
  kVoltAmperes = 8,
  kKilovoltAmperes = 9,
  kMegavoltAmperes = 10,
  kVoltAmperesReactive = 11,
  kKilovoltAmperesReactive = 12,
  kMegavoltAmperesReactive = 13,
  kDegreesPhase = 14,
  kPowerFactor = 15,
  kJoules = 16,
  kKilojoules = 17,
  kWattHours = 18,
  kKilowattHours = 19,
  kBtus = 20,
  kTherms = 21,
  kTonHours = 22,
  kJoulesPerKilogramDryAir = 23,
  kBtusPerPoundDryAir = 24,
  kCyclesPerHour = 25,
  kCyclesPerMinute = 26,
  kHertz = 27,
  kGramsOfWaterPerKilogramDryAir = 28,
  kPercentRelativeHumidity = 29,
  kMillimeters = 30,
  kMeters = 31,
  kInches = 32,
  kFeet = 33,
  kWattsPerSquareFoot = 34,
  kWattsPerSquareMeter = 35,
  kLumens = 36,
  kLux = 37,
  kFootCandles = 38,
  kKilograms = 39,
  kPoundsMass = 40,
  kTons = 41,
  kKilogramsPerSecond = 42,
  kKilogramsPerMinute = 43,
  kKilogramsPerHour = 44,
  kPoundsMassPerMinute = 45,
  kPoundsMassPerHour = 46,
  kWatts = 47,
  kKilowatts = 48,
  kMegawatts = 49,
  kBtusPerHour = 50,
  kHorsepower = 51,
  kTonsRefrigeration = 52,
  kPascals = 53,
  kKilopascals = 54,
  kBars = 55,
  kPoundsForcePerSquareInch = 56,
  kCentimetersOfWater = 57,
  kInchesOfWater = 58,
  kMillimetersOfMercury = 59,
  kCentimetersOfMercury = 60,
  kInchesOfMercury = 61,
  kDegreesCelsius = 62,
  kKelvins = 63,
  kDegreesFahrenheit = 64,
  kDegreeDaysCelsius = 65,
  kDegreeDaysFahrenheit = 66,
  kYears = 67,
  kMonths = 68,
  kWeeks = 69,
  kDays = 70,
  kHours = 71,
  kMinutes = 72,
  kSeconds = 73,
  kMetersPerSecond = 74,
  kKilometersPerHour = 75,
  kFeetPerSecond = 76,
  kFeetPerMinute = 77,
  kMilesPerHour = 78,
  kCubicFeet = 79,
  kCubicMeters = 80,
  kImperialGallons = 81,
  kLiters = 82,
  kUsGallons = 83,
  kCubicFeetPerMinute = 84,
  kCubicMetersPerSecond = 85,
  kImperialGallonsPerMinute = 86,
  kLitersPerSecond = 87,
  kLitersPerMinute = 88,
  kUsGallonsPerMinute = 89,
  kDegreesAngular = 90,
  kDegreesCelsiusPerHour = 91,
  kDegreesCelsiusPerMinute = 92,
  kDegreesFahrenheitPerHour = 93,
  kDegreesFahrenheitPerMinute = 94,
  kNoUnits = 95,
  kPartsPerMillion = 96,
  kPartsPerBillion = 97,
  kPercent = 98,
  kPercentPerSecond = 99,
  kPerMinute = 100,
  kPerSecond = 101,
  kPsiPerDegreeFahrenheit = 102,
  kRadians = 103,
  kRevolutionsPerMinute = 104,
  kCurrency1 = 105,
  kCurrency2 = 106,
  kCurrency3 = 107,
  kCurrency4 = 108,
  kCurrency5 = 109,
  kCurrency6 = 110,
  kCurrency7 = 111,
  kCurrency8 = 112,
  kCurrency9 = 113,
  kCurrency10 = 114,
  kSquareInches = 115,
  kSquareCentimeters = 116,
  kBtusPerPound = 117,
  kCentimeters = 118,
  kPoundsMassPerSecond = 119,
  kDeltaDegreesFahrenheit = 120,
  kDeltaDegreesKelvin = 121,
  kKilohms = 122,
  kMegohms = 123,
  kMillivolts = 124,
  kKilojoulesPerKilogram = 125,
  kMegajoules = 126,
  kJoulesPerKelvin = 127,
  kJoulesPerKilogramKelvin = 128,
  kKilohertz = 129,
  kMegahertz = 130,
  kPerHour = 131,
  kMilliwatts = 132,
  kHectopascals = 133,
  kMillibars = 134,
  kCubicMetersPerHour = 135,
  kLitersPerHour = 136,
  kKilowattHoursPerSquareMeter = 137,
  kKilowattHoursPerSquareFoot = 138,
  kMegajoulesPerSquareMeter = 139,
  kMegajoulesPerSquareFoot = 140,
  kWattsPerSquareMeterKelvin = 141,
  kCubicFeetPerSecond = 142,
  kPercentObscurationPerFoot = 143,
  kPercentObscurationPerMeter = 144,
  kMilliohms = 145,
  kMegawattHours = 146,
  kKiloBtus = 147,
  kMegaBtus = 148,
  kKilojoulesPerKilogramDryAir = 149,
  kMegajoulesPerKilogramDryAir = 150,
  kKilojoulesPerKelvin = 151,
  kMegajoulesPerKelvin = 152,
  kNewtons = 153,
  kGramsPerSecond = 154,
  kGramsPerMinute = 155,
  kTonsPerHour = 156,
  kKiloBtusPerHour = 157,
  kHundredthsSeconds = 158,
  kMilliseconds = 159,
  kNewtonMeters = 160,
  kMillimetersPerSecond = 161,
  kMillimetersPerMinute = 162,
  kMetersPerMinute = 163,
  kMetersPerHour = 164,
  kCubicMetersPerMinute = 165,
  kMetersPerSecondPerSecond = 166,
  kAmperesPerMeter = 167,
  kAmperesPerSquareMeter = 168,
  kAmpereSquareMeters = 169,
  kFarads = 170,
  kHenries = 171,
  kOhmMeters = 172,
  kSiemens = 173,
  kSiemensPerMeter = 174,
  kTeslas = 175,
  kVoltsPerDegreeKelvin = 176,
  kVoltsPerMeter = 177,
  kWebers = 178,
  kCandelas = 179,
  kCandelasPerSquareMeter = 180,
  kKelvinsPerHour = 181,
  kDegreesKelvinPerMinute = 182,
  kJouleSeconds = 183,
  kRadiansPerSecond = 184,
  kSquareMetersPerNewton = 185,
  kKilogramsPerCubicMeter = 186,
  kNewtonSeconds = 187,
  kNewtonsPerMeter = 188,
  kWattsPerMeterPerDegreeKelvin = 189,
  kMicroSiemens = 190,
  kCubicFeetPerHour = 191,
  kUsGallonsPerHours = 192,
  kKilometers = 193,
  kMicrometers = 194,
  kGrams = 195,
  kMilligrams = 196,
  kMilliliters = 197,
  kMillilitersPerSecond = 198,
  kDecibels = 199,
  kDecibelsMillivolt = 200,
  kDecibelsVolt = 201,
  kMillisiemens = 202,
  kWattHoursReactive = 203,
  kKilowattHoursReactive = 204,
  kMegawattHoursReactive = 205,
  kMillimetersOfWater = 206,
  kPerMille = 207,
  kGramsPerGram = 208,
  kKilogramsPerKilogram = 209,
  kGramsPerKilogram = 210,
  kMilligramsPerGram = 211,
  kMilligramsPerKilogram = 212,
  kGramsPerMilliliter = 213,
  kGramsPerLiter = 214,
  kMilligramsPerLiter = 215,
  kMicrogramsPerLiter = 216,
  kGramsPerCubicMeter = 217,
  kMilligramsPerCubicMeter = 218,
  kMicrogramsPerCubicMeter = 219,
  kNanogramsPerCubicMeter = 220,
  kGramsPerCubicCentimeter = 221,
  kBecquerels = 222,
  kKilobecquerels = 223,
  kMegabecquerels = 224,
  kGray = 225,
  kMilligray = 226,
  kMicrogray = 227,
  kSieverts = 228,
  kMillisieverts = 229,
  kMicrosieverts = 230,
  kMicrosievertsPerHour = 231,
  kDecibelsA = 232,
  kNephelometricTurbidityUnit = 233,
  kPh = 234,
  kGramsPerSquareMeter = 235,
  kMinutesPerDegreeKelvin = 236,
  kOhmMeterSquaredPerMeter = 237,
  kAmpereSeconds = 238,
  kVoltAmpereHours = 239,
  kKilovoltAmpereHours = 240,
  kMegavoltAmpereHours = 241,
  kVoltAmpereHoursReactive = 242,
  kKilovoltAmpereHoursReactive = 243,
  kMegavoltAmpereHoursReactive = 244,
  kVoltSquareHours = 245,
  kAmpereSquareHours = 246,
  kJoulePerHours = 247,
  kCubicFeetPerDay = 248,
  kCubicMetersPersDay = 249,
  kWattHoursPerCubicMeters = 250,
  kJoulesPerCubicMeter = 251,
  kMolePercent = 252,
  kPascalSeconds = 253,
  kMillionStandardCubicFeetPerMinute = 254,
  kStandardCubicFeetPerDay = -17728,
  kMillionStandardCubicFeetPerDay = -17727,
  kThousandCubicFeetPerDay = -17726,
  kThousandStandardCubicFeetPerDay = -17725,
  kPoundsMassPerDay = -17724,
  kMillirems = -17722,
  kMilliremsPerHour = -17721,

  //Custom codes
  kTimestampMicroseconds = 2147483647,
  kTimestampMilliseconds = 2147483646,
  kTimestampSeconds = 2147483645,
  kHeatingCostAllocatorUnits = 2147483644
};

}
#endif //LIBHOMEGEAR_BASE_SRC_DEVICEDESCRIPTION_UNITCODE_H_
